# rubocop:todo all
# Copyright (C) 2009-2020 MongoDB Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require "spec_helper"

describe TrueClass do

  describe "#to_bson" do

    let(:obj)  { true }
    let(:bson) { 1.chr }
    let(:type) { 8.chr }

    it_behaves_like "a bson element"
    it_behaves_like "a serializable bson element"
  end

  describe '#as_extended_json' do
    let(:object) { true }

    it_behaves_like '#as_extended_json returns self'
    it_behaves_like 'an Extended JSON serializable object'
  end
end
